Line class

Constructors

Line(RectComponent startWidget, RectComponent endWidget)

Properties

end → Offset
no setter
endWidget → RectComponent
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Offset
no setter
startWidget → RectComponent
final
uid ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited