RectPosition class

Constructors

RectPosition(Offset targetPosition, Offset centerTopPosition, Offset centerBottomPosition, Offset centerLeftPosition, Offset centerRightPosition)

Properties

centerBottomPosition → Offset
final
centerLeftPosition → Offset
final
centerRightPosition → Offset
final
centerTopPosition → Offset
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetPosition → Offset
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited